All notable changes will be noted in this file, whenever a tagged
version is made

## [0.2.6] 16/08/2023

Bugifx release. Fixes another compatibility issue with Cython 3.0.0. Increase total mass upper limit to 1e12.

## [0.2.5] 01/08/2023

Bugfix release. Fixes a compatibility issue with Cython 3.0.0.

## [0.2.4] 15/05/2023

Bugfix release. Fixes a rare issue with quaternion overflow, which occured after attachment.



## [0.2.3] 10/05/2023

Bugfix release. Fixes a minor issue where the correct message was not included in ValueError,
which was needed for `bilby` error handling

## [0.2.2] 02/05/2023

Bugfix release. Fixes a bug in stopping conditions of PN integration at very low frequency.
	
## [0.2.0] 06/04/2023

Initial release for conda. Several housekeeping improvements, add references to papers.

## [0.1.0] 31/03/2023

Initial release of the aligned-spin model SEOBNRv5HM and the
precessing model SEOBNRv5PHM.
